import React, { useEffect, useState, useRef } from "react";
import IconButton from "@mui/material/IconButton";
import axios from "axios";
import Image from "next/image";
import Link from "next/link";
import PaginationComponent from "../Pagination";
import { Navigation, Pagination, Scrollbar, A11y } from "swiper/modules";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import {
  Analytics,
  LocationIcon,
  EditIcon,
  DeleteIcon,
  SearchIcon,
} from "@/components/Icons";
import "./style.css";

const DeleteModal = ({ onClose, onDelete }) => (
  <div className="fixed inset-0 z-50 flex items-center justify-center bg-black bg-opacity-50">
    <div className="bg-white p-6 rounded-[12px] shadow-lg w-96">
      <h2 className="text-lg text-[#8D7C3B] font-semibold mb-4">
        Delete Confirmation
      </h2>
      <p>Are you sure you want to delete this listing?</p>
      <div className="flex justify-end mt-6">
        <button
          onClick={onClose}
          className="mr-4 px-4 py-2 bg-gray-200 text-gray-800 rounded"
        >
          Cancel
        </button>
        <button
          onClick={onDelete}
          className="px-4 py-2 bg-[#8D7C3B] text-white rounded"
        >
          Delete
        </button>
      </div>
    </div>
  </div>
);

const MyListingTab = () => {
  const [selectedTabIdx, setSelectedTabIdx] = useState(0);
  const [currentPage, setCurrentPage] = useState(1);
  const totalPages = 4;
  const [allListings, setAllListings] = useState([]);
  const [boatListings, setBoatListings] = useState([]);
  const [propertyListings, setPropertyListings] = useState([]);
  const [carListings, setCarListings] = useState([]);
  const [jewelryListings, setJewelryListings] = useState([]);
  const [isLoading, setIsLoading] = useState(true);
  const [preious, setPreious] = useState(false);
  const [next, setNext] = useState(false);
  const [isDeleteModalOpen, setIsDeleteModalOpen] = useState(false);
  const [listingToDelete, setListingToDelete] = useState(null);
  const [searchTerm, setSearchTerm] = useState("");
  const swiperRefs = useRef({});

  const handlePrevSlide = (id) => {
    if (swiperRefs.current[id]) {
      swiperRefs.current[id].slidePrev();
    }
  };

  const handleNextSlide = (id) => {
    if (swiperRefs.current[id]) {
      swiperRefs.current[id].slideNext();
    }
  };

  const handlePageChange = (pageNumber) => {
    setCurrentPage(pageNumber);
  };

  const fetchListingsData = async () => {
    try {
      const [boatResponse, propertyResponse, carResponse, jewelryResponse] =
        await Promise.all([
          axios.get(`${process.env.NEXT_PUBLIC_BASE_URL}/boat`),
          axios.get(`${process.env.NEXT_PUBLIC_BASE_URL}/property`),
          axios.get(`${process.env.NEXT_PUBLIC_BASE_URL}/car`),
          axios.get(`${process.env.NEXT_PUBLIC_BASE_URL}/jewelry`),
        ]);

      setBoatListings(boatResponse.data);
      setPropertyListings(propertyResponse.data);
      setCarListings(carResponse.data);
      setJewelryListings(jewelryResponse.data);

      const combinedListings = [
        ...boatResponse.data,
        ...propertyResponse.data,
        ...carResponse.data,
        ...jewelryResponse.data,
      ];

      setAllListings(combinedListings);
      setIsLoading(false);
    } catch (error) {
      console.error("Error fetching listing data:", error);
      setIsLoading(false);
    }
  };

  useEffect(() => {
    fetchListingsData();
  }, []);

  const tabs = [
    { name: "All Listing", current: true },
    { name: "Properties For Sell", current: false },
    { name: "Cars For Sell", current: false },
    { name: "Jewelleries For Sell", current: false },
    { name: "Boats For Sell", current: false },
  ];

  const getShortTitle = (title) => {
    const words = title.split(" ");
    return words.length > 3 ? `${words.slice(0, 3).join(" ")}...` : title;
  };

  const getDynamicLink = (assetType, slug) => {
    let assetTypeText;
    switch (assetType) {
      case "Property For Lease":
      case "Property For Sale":
        assetTypeText = "property";
        break;
      case "Car For Sale":
        assetTypeText = "car";
        break;
      case "Jewellery For Sale":
        assetTypeText = "jewellery";
        break;
      case "Boats For Sale":
        assetTypeText = "boat";
        break;
      default:
        assetTypeText = assetType.toLowerCase();
    }
    return `/${assetTypeText}/${slug}`;
  };

  const renderListingDetails = (listing) => {
    switch (listing.assetType) {
      case "Property For Lease":
      case "Property For Sale":
        return (
          <div className="flex flex-wrap gap-3 items-center mb-3">
            <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
            <span>{listing.bedrooms} Beds</span>
            <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
            <span>{listing.bathrooms} Baths</span>
            <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
            <span>{listing.sizeSQFT} Sqft</span>
          </div>
        );
      case "Car For Sale":
        return (
          <div className="flex gap-3 items-center mb-3">
            <span className="text-[#002D4F]">Model: {listing.model}</span>
            <span className="text-[#002D4F]">
              Used: {listing.bodyCondition}
            </span>
            <span className="text-[#002D4F]">
              Steering: {listing.steeringSide}
            </span>
          </div>
        );
      case "Jewellery For Sale":
        return (
          <div className="flex flex-wrap gap-3 items-center mb-3">
            <span>Age: {listing.age}</span>
            <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
            <span>Grams: {listing.grams}</span>
          </div>
        );
      case "Boats For Sale":
        return (
          <div className="flex flex-wrap gap-3 items-center mb-3">
            <span>Condition: {listing.condition}</span>
            <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
            <span>Length: {listing.length}</span>
          </div>
        );
      default:
        return null;
    }
  };

  const handleAddListingClick = () => {
    window.location.href = "/dashboard/property-listing";
  };

  const handleDeleteClick = (listing) => {
    setListingToDelete(listing);
    setIsDeleteModalOpen(true);
  };

  const handleDeleteConfirm = () => {
    // Implement your delete logic here
    setIsDeleteModalOpen(false);
    console.log("Deleted listing:", listingToDelete);
  };

  const renderListings = (listings) => {
    const handleEditClick = (assetType) => {
      let targetUrl = "";
      switch (assetType) {
        case "Property For Lease":
        case "Property For Sale":
          targetUrl = "/dashboard/property-listing";
          break;
        case "Car For Sale":
          targetUrl = "/dashboard/car-listing";
          break;
        case "Jewellery For Sale":
          targetUrl = "/dashboard/jewelry-listing";
          break;
        case "Boats For Sale":
          targetUrl = "/dashboard/boat-listing";
          break;
        default:
          break;
      }

      if (targetUrl) {
        window.location.href = targetUrl;
      }
    };

    return listings.map((listing, i) => {
      let assetTypeText;
      switch (listing.assetType) {
        case "Property For Lease":
        case "Property For Sale":
          assetTypeText = "property";
          break;
        case "Car For Sale":
          assetTypeText = "car";
          break;
        case "Jewellery For Sale":
          assetTypeText = "jewellery";
          break;
        case "Boats For Sale":
          assetTypeText = "boat";
          break;
        default:
          assetTypeText = listing.assetType;
      }

      return (
        <div
          key={i}
          className="relative flex p-5 flex-col gap-4 xl:gap-10 items-center sm:flex-row custom-shadow overflow-x-hidden"
        >
          <div className="absolute top-2 right-2 z-50 flex gap-2">
            {/* Delete Icon */}
            <IconButton
              style={{
                background: "transparent",
              }}
              onClick={(e) => {
                e.stopPropagation();
                handleDeleteClick(listing);
              }}
            >
              <DeleteIcon className="py-3" />
            </IconButton>

            {/* Edit Icon with IconButton */}
            <IconButton
              style={{
                background: "transparent",
              }}
              onClick={(e) => {
                e.stopPropagation();
                handleEditClick(listing.assetType);
              }}
            >
              <EditIcon />
            </IconButton>
          </div>

          <div
            className="w-full sm:w-1/2 relative"
            style={{ maxWidth: "350px" }}
          >
            {/* Previous arrow */}
            <div
              onClick={() => handlePrevSlide(i)}
              className={`absolute top-[30%] left-10 z-40 h-[100px] w-[25px] flex items-center justify-center ${
                preious ? "bg-white" : "bg-[#FFFFFF]"
              }`}
            >
              <div className=" px-2 py-1 rounded">
                <img
                  src={"/icons/golden-arrow-previous.png"}
                  alt="previous"
                  className=""
                />
              </div>
            </div>
            {/* Image slider */}
            <Swiper
              spaceBetween={0}
              slidesPerView={1}
              hashNavigation={{
                watchState: true,
              }}
              loop={true}
              pagination={{ clickable: true }}
              scrollbar={{ draggable: true }}
              style={{ maxWidth: "312px", width: "100%", height: "250px" }} // Adjusted height to match your design
              modules={[Navigation, Pagination, Scrollbar, A11y]}
              onSwiper={(swiper) => {
                swiperRefs.current[i] = swiper;
              }}
            >
              {listing.pictures?.images.map((image, index) => (
                <SwiperSlide key={index}>
                  <Image
                    className="rounded-lg !w-[314px] !h-[250px]"
                    src={image.url}
                    height={253}
                    width={314}
                    alt={listing.title}
                  />
                </SwiperSlide>
              ))}
            </Swiper>
            {/* Next arrow */}
            <div
              onClick={() => handleNextSlide(i)}
              className={`absolute top-[30%] right-10 z-40 h-[100px] w-[25px] flex items-center justify-center ${
                next ? "bg-white" : "bg-[#FFFFFF]"
              }`}
            >
              <div className="px-2 py-1 rounded">
                <img
                  src={"/icons/golden-arrow-previous.png"}
                  className="transform rotate-180"
                  alt="next"
                />
              </div>
            </div>
          </div>
          {/* Details section */}
          <div className="max-w-[450px] flex flex-col">
            <span>Sale {assetTypeText}</span>
            <Link href={getDynamicLink(listing.assetType, listing.slug)}>
              <h2 className="fs-40 capitalize font-semibold">
                {getShortTitle(listing.title)}
              </h2>
            </Link>
            <p className="text-prussianBlue mb-2 font-medium">
              Revenue: {listing.price}
            </p>
            <p className="text-prussianBlue mb-2 font-medium">
              Sale By: {listing.sellerType}
            </p>
            {renderListingDetails(listing)}
            <div className="flex gap-3 items-center mb-3">
              <LocationIcon className="text-prussianBlue" />
              <p className="whitespace-normal">{listing.country}</p>
            </div>
            <div className="flex gap-2 items-center">
              <Analytics />
              <p>Analytics</p>
            </div>
          </div>
        </div>
      );
    });
  };

  const filterListings = (listings) => {
    if (!searchTerm) return listings;
    return listings.filter((listing) =>
      listing.title.toLowerCase().includes(searchTerm.toLowerCase())
    );
  };

  return (
    <>
      <div className="flex items-center justify-between mb-4">
        <span className="text-lg text-prussianBlue/40">My Listing</span>
        <div className="flex items-center ml-auto">
          <div className="flex items-center border border-[#D9D9D9] rounded-md overflow-hidden mr-4">
            <input
              type="text"
              placeholder="Search..."
              value={searchTerm}
              onChange={(e) => setSearchTerm(e.target.value)}
              className="pl-3 py-1 w-full text-gray-700 focus:outline-none"
            />
            <button className="bg-gray mx-1 my-1 px-2 py-2 rounded">
              <SearchIcon />
            </button>
          </div>
          <button
            className="px-6 py-3 primary-gradient text-white"
            onClick={handleAddListingClick}
          >
            Add Listing
          </button>
        </div>
      </div>

      <div className="custom-shadow rounded">
        <div className="primary-gradient border border-black rounded px-12 overflow-x-auto">
          <nav className="flex justify-between gap-4 w-full" aria-label="Tabs">
            {tabs.map((tab, i) => (
              <a
                key={tab.name}
                className={`
                  ${
                    i === selectedTabIdx
                      ? "text-white border-b-4 border-white focus:outline-none "
                      : ""
                  }
                  whitespace-nowrap py-4 cursor-pointer text-xl`}
                onClick={() => setSelectedTabIdx(i)}
              >
                {tab.name}
              </a>
            ))}
          </nav>
        </div>
        <div className="p-10 flex flex-col gap-6">
          {isLoading ? (
            <p>Please wait...</p>
          ) : (
            <>
              {selectedTabIdx === 0 &&
                renderListings(filterListings(allListings))}
              {selectedTabIdx === 1 &&
                renderListings(filterListings(propertyListings))}
              {selectedTabIdx === 2 &&
                renderListings(filterListings(carListings))}
              {selectedTabIdx === 3 &&
                renderListings(filterListings(jewelryListings))}
              {selectedTabIdx === 4 &&
                renderListings(filterListings(boatListings))}
              {searchTerm &&
                !filterListings(allListings).length &&
                !filterListings(propertyListings).length &&
                !filterListings(carListings).length &&
                !filterListings(jewelryListings).length &&
                !filterListings(boatListings).length && (
                  <p>No listings were found.</p>
                )}
            </>
          )}
          {!isLoading && (
            <PaginationComponent
              className="!border-prussianBlue !text-prussianBlue"
              currentPage={currentPage}
              totalPages={totalPages}
              onPageChange={handlePageChange}
            />
          )}
        </div>
      </div>

      {isDeleteModalOpen && (
        <DeleteModal
          onClose={() => setIsDeleteModalOpen(false)}
          onDelete={handleDeleteConfirm}
        />
      )}
    </>
  );
};
export default MyListingTab;
